@@ -32,9 +32,25 @@ class Python2(ViaGlobalRefVirtualenvBuiltin, Python2Supports):
         else:
             custom_site_text = custom_site.read_text()
         expected = json.dumps([os.path.relpath(ensure_text(str(i)), ensure_text(str(site_py))) for i in self.libs])
+
         custom_site_text = custom_site_text.replace("___EXPECTED_SITE_PACKAGES___", expected)
+
+        reload_code = os.linesep.join("    {}".format(i) for i in self.reload_code.splitlines()).lstrip()
+        custom_site_text = custom_site_text.replace("# ___RELOAD_CODE___", reload_code)
+
+        skip_rewrite = os.linesep.join("            {}".format(i) for i in self.skip_rewrite.splitlines()).lstrip()
+        custom_site_text = custom_site_text.replace("# ___SKIP_REWRITE____", skip_rewrite)
+
         site_py.write_text(custom_site_text)
 
+    @property
+    def reload_code(self):
+        return 'reload(sys.modules["site"])  # noqa # call system site.py to setup import libraries'
+
+    @property
+    def skip_rewrite(self):
+        return ""
+
     @classmethod
     def sources(cls, interpreter):
         for src in super(Python2, cls).sources(interpreter):
