@@ -1,11 +1,13 @@
 from __future__ import absolute_import, unicode_literals
 
+import os
 from argparse import Namespace
 
 import pytest
 
 from virtualenv.config.ini import IniConfig
 from virtualenv.run import session_via_cli
+from virtualenv.util.path import Path
 
 
 def parse_cli(args):
@@ -33,3 +35,14 @@ def test_value_bad(monkeypatch, caplog, empty_conf):
     assert len(caplog.messages) == 1
     assert "env var VIRTUALENV_VERBOSE failed to convert" in caplog.messages[0]
     assert "invalid literal" in caplog.messages[0]
+
+
+def test_extra_search_dir(tmp_path, monkeypatch):
+    monkeypatch.chdir(tmp_path)
+    value = "a{}0{}b{}c".format(os.linesep, os.linesep, os.pathsep)
+    monkeypatch.setenv("VIRTUALENV_EXTRA_SEARCH_DIR", value)
+    (tmp_path / "a").mkdir()
+    (tmp_path / "b").mkdir()
+    (tmp_path / "c").mkdir()
+    result = parse_cli(["venv"])
+    assert result.seeder.extra_search_dir == [Path("a").resolve(), Path("b").resolve(), Path("c").resolve()]
